"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const childProcess = require("child_process");
const path = require("path");
const getOS_1 = require("./getOS");
const printErrorsAndExit_1 = require("./printErrorsAndExit");
const readConfig_1 = require("./readConfig");
function link(projDir, config, build, isMainProject, context) {
    return __awaiter(this, void 0, void 0, function* () {
        const allDeps = (config.localDependencies || []).concat(config.localDevDependencies || []);
        for (const dep of allDeps) {
            const depConfig = yield readConfig_1.default(dep.location);
            if (depConfig && !context.alreadyBuilt.includes(dep.location)) {
                yield link(dep.location, depConfig, true, false, context);
                context.alreadyBuilt.push(dep.location);
            }
        }
        /*
          The shell script will...
          1. We switch to the dependecy directory directory.
          2. Do an npm link <dep-name>
          3. Check if the dependency directory has changed (compare md5 of contents)
          4. If so (3), do a build
          5. If so (3), npm link
        */
        console.log(`Building ${projDir}...`);
        for (const dep of allDeps) {
            console.log(`Linking to ${dep.name} from ${config.name}...`);
            try {
                childProcess.execSync(`cd "${projDir}" && npm link ${dep.name}`);
            }
            catch (ex) {
                printErrorsAndExit_1.default(ex, config.name);
            }
        }
        if (!build) {
            console.log(`Completed linking local dependencies for ${config.name}.`);
        }
        else {
            try {
                const linkScript = path.join(__dirname, `link-${getOS_1.default()}.sh`);
                const result = childProcess.execSync(`${linkScript} "${projDir}" "${config.build}" ${context.argv.force ? "buildalways" : "buildifnew"} ${isMainProject ? "nolink" : "link"}`);
                console.log(result.toString());
            }
            catch (ex) {
                printErrorsAndExit_1.default(ex, config.name);
            }
        }
    });
}
exports.default = link;
//# sourceMappingURL=link.js.map